{% block search_form %}
    <form action="{% url 'search_results' %}" method="get">
        <div class="field">
            <div class="control">
                <input class="input" name="q" type="text" placeholder="Search for a name.">
            </div>
        </div>
        <div class="field">
            <div class="control">
                <input class="button is-link" type="submit" value="Search">
            </div>
        </div>
    </form>
{% endblock search_form %}
